==> seedsui-react-3.7.9.tgz: package/es/ContainerPull/BottomRefreshing.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React, { forwardRef, useRef, useImperativeHandle, useContext } from 'react';
import Context from './../Context/instance.js';

var BottomError = forwardRef(function (_ref, ref) {
  var children = _ref.children,
      others = _objectWithoutProperties(_ref, ['children']);

  // context
  var context = useContext(Context) || {};
  var locale = context.locale || {};

  var refEl = useRef(null);
  useImperativeHandle(ref, function () {
    return refEl.current;
  });

  return React.createElement(
    'div',
    _extends({ className: 'SID-Dragrefresh-BottomContainer containerpull-pull', style: { height: '50px' } }, others),
    !children && React.createElement(
      'div',
      { className: 'containerpull-pull-box' },
      React.createElement('div', { className: 'containerpull-pull-icon containerpull-pull-icon-loading' }),
      React.createElement(
        'div',
        { className: 'containerpull-pull-caption' },
        locale['loading'] || '正在加载...'
      )
    ),
    children
  );
});

export default BottomError;

==> seedsui-react-4.0.2.tgz: package/es/ContainerPull/BottomRefreshing.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React, { forwardRef, useRef, useImperativeHandle, useContext } from 'react';
import Context from './../Context/instance.js';

var BottomError = forwardRef(function (_ref, ref) {
  var children = _ref.children,
      others = _objectWithoutProperties(_ref, ['children']);

  // context
  var context = useContext(Context) || {};
  var locale = context.locale || function (key) {
    return key || '';
  };

  var refEl = useRef(null);
  useImperativeHandle(ref, function () {
    return refEl.current;
  });

  return React.createElement(
    'div',
    _extends({ className: 'SID-Dragrefresh-BottomContainer containerpull-pull', style: { height: '50px' } }, others),
    !children && React.createElement(
      'div',
      { className: 'containerpull-pull-box' },
      React.createElement('div', { className: 'containerpull-pull-icon containerpull-pull-icon-loading' }),
      React.createElement(
        'div',
        { className: 'containerpull-pull-caption' },
        locale('loading') || '正在加载...'
      )
    ),
    children
  );
});

export default BottomError;
